@@ -43,7 +43,7 @@ namespace BibTeX
     bool FileExporterRTF::save( TQIODevice* iodevice, const File* bibtexfile, TQStringList *errorLog )
     {
         m_mutex.lock();
-        bool result = FALSE;
+        bool result = false;
 
         TQFile bibtexFile( bibTeXFilename );
         if ( bibtexFile.open( IO_WriteOnly ) )
@@ -64,7 +64,7 @@ namespace BibTeX
     bool FileExporterRTF::save( TQIODevice* iodevice, const Element* element, TQStringList *errorLog )
     {
         m_mutex.lock();
-        bool result = FALSE;
+        bool result = false;
 
         TQFile bibtexFile( bibTeXFilename );
         if ( bibtexFile.open( IO_WriteOnly ) )
@@ -97,9 +97,9 @@ namespace BibTeX
         TQStringList cmdLines = TQStringList::split( '|', "latex bibtex-to-rtf.tex|bibtex bibtex-to-rtf|latex bibtex-to-rtf.tex|latex2rtf bibtex-to-rtf.tex" );
 
         if ( writeLatexFile( laTeXFilename ) && runProcesses( cmdLines, errorLog ) && writeFileToIODevice( outputFilename, iodevice ) )
-            return TRUE;
+            return true;
         else
-            return FALSE;
+            return false;
     }
 
     bool FileExporterRTF::writeLatexFile( const TQString &filename )
@@ -124,10 +124,10 @@ namespace BibTeX
             ts << "\\bibliography{bibtex-to-rtf}\n";
             ts << "\\end{document}\n";
             latexFile.close();
-            return TRUE;
+            return true;
         }
         else
-            return FALSE;
+            return false;
 
     }
 
