@@ -41,7 +41,7 @@ namespace BibTeX
     class FileImporterBibTeX : public FileImporter
     {
     public:
-        FileImporterBibTeX( bool personFirstNameFirst = FALSE, TQString encoding = "latex" );
+        FileImporterBibTeX( bool personFirstNameFirst = false, TQString encoding = "latex" );
         ~FileImporterBibTeX();
 
         File* load( TQIODevice *iodevice );
