@@ -35,7 +35,7 @@ namespace KBibTeX
 {
     class SettingsFileIO : public TQWidget
     {
-        Q_OBJECT
+        TQ_OBJECT
     public:
         SettingsFileIO( TQWidget *parent = 0, const char *name = 0 );
         ~SettingsFileIO();
