@@ -46,7 +46,7 @@ namespace KBibTeX
     */
     class WebQueryWidget : public TQWidget
     {
-        Q_OBJECT
+        TQ_OBJECT
     public:
         WebQueryWidget( TQWidget *parent, const char *name = 0 );
         virtual bool searchPossible();
@@ -74,7 +74,7 @@ namespace KBibTeX
     */
     class WebQuery : public TQObject
     {
-        Q_OBJECT
+        TQ_OBJECT
     public:
         enum Status { statusSuccess, statusError, statusAborted, statusInvalidQuery, statusInsufficientPermissions };
 
@@ -124,7 +124,7 @@ namespace KBibTeX
 
     class WebQueryWizard: public TQWidget
     {
-        Q_OBJECT
+        TQ_OBJECT
     public:
         ~WebQueryWizard();
 
