@@ -29,7 +29,7 @@ namespace KBibTeX
     */
     class WebQueryCitebaseWidget : public WebQueryWidget
     {
-        Q_OBJECT
+        TQ_OBJECT
     public:
         WebQueryCitebaseWidget( TQWidget *parent, const char *name = 0 );
     };
@@ -39,7 +39,7 @@ namespace KBibTeX
     */
     class WebQueryCitebase : public WebQuery
     {
-        Q_OBJECT
+        TQ_OBJECT
     public:
         WebQueryCitebase( TQWidget* parent );
         virtual ~WebQueryCitebase();
